=======
History
=======

0.0.2 (2025-03-11)
------------------

* base de chibi site para descargar paginas y procesarlas con beautiful soup

0.0.1 (2025-03-03)
------------------

* First release on PyPI.
